[DebianGIS-dev] r1715 - packages/josm/trunk/debian

nd-guest at alioth.debian.org nd-guest at alioth.debian.org
Sun Jul 13 19:45:11 UTC 2008


Author: nd-guest
Date: 2008-07-13 19:45:10 +0000 (Sun, 13 Jul 2008)
New Revision: 1715

Modified:
   packages/josm/trunk/debian/README.Debian
   packages/josm/trunk/debian/josm.sh
Log:
Update readme and wrapper script for openjdk


Modified: packages/josm/trunk/debian/README.Debian
===================================================================
--- packages/josm/trunk/debian/README.Debian	2008-07-13 19:44:43 UTC (rev 1714)
+++ packages/josm/trunk/debian/README.Debian	2008-07-13 19:45:10 UTC (rev 1715)
@@ -1,15 +1,10 @@
 Josm for Debian
 ---------------
 
-Josm should work using one of the following as /usr/bin/java:
-
-    * /usr/bin/gij-4.1
-    * /usr/bin/jamvm
-    * any of SUN's java (non-free)
-
-This can be setup by exporting the JAVACMD or JAVA_HOME environment 
-variable before running josm.
+By default josm is launched using OpenJDK-6. This can be overridden
+by exporting the JAVACMD or JAVA_HOME environment variables before
+running josm.
 Note that JOSM doesn't follow the alternative system 
 in /etc/alternatives/ that is usually used on Debian systems.
 
- -- Andreas Putzo <andreas at putzo.net>  Tue, 25 Mar 2008 22:40:12 +0000
+ -- Andreas Putzo <andreas at putzo.net>  Sun, 13 Jul 2008 19:16:59 +0000

Modified: packages/josm/trunk/debian/josm.sh
===================================================================
--- packages/josm/trunk/debian/josm.sh	2008-07-13 19:44:43 UTC (rev 1714)
+++ packages/josm/trunk/debian/josm.sh	2008-07-13 19:45:10 UTC (rev 1715)
@@ -2,11 +2,9 @@
 # Simple wrapper script used to start JOSM in Debian
 set -e
 
-# First, the users preference as defined by $JAVA_HOME.  Next, the
-# other JVMs known to work with josm, with the one working best
-# first, and the less functional ones after that.  Override to a
-# specific one using $JAVACMD
-JAVA_CMDS="$JAVA_HOME/bin/java /usr/lib/jvm/java-6-sun/jre/bin/java /usr/lib/jvm/java-1.5.0-sun/jre/bin/java /usr/bin/jamvm /usr/bin/gij-4.1"
+# First, the users preference as defined by $JAVA_HOME. Next, use OpenJDK.
+# Override to a specific one using $JAVACMD
+JAVA_CMDS="$JAVA_HOME/bin/java /usr/lib/jvm/java-6-openjdk/bin/java"
 
 for jcmd in $JAVA_CMDS; do 
     if [ -x "$jcmd" -a -z "${JAVACMD}" ]; then
@@ -19,7 +17,5 @@
     exec $JAVACMD -jar /usr/share/josm/josm.jar "$@"
 else    
     echo "No valid JVM found to run JOSM."
-    echo "Please install one of those mentioned in README.Debian"
-    echo "or set the JAVACMD environment variable prior running josm."
     exit 1
 fi




More information about the Pkg-grass-devel mailing list